import 'package:flutter/material.dart';
import 'package:flutter_markdown/flutter_markdown.dart';
import 'package:solaragent/models/feed.dart';
import 'package:markdown/markdown.dart' as md;
import 'package:url_launcher/url_launcher.dart';
import 'package:url_launcher/url_launcher_string.dart';

class ArticleContent extends StatelessWidget {
  final Feed item;
  final bool brief;

  const ArticleContent({super.key, required this.item, required this.brief});

  @override
  Widget build(BuildContext context) {
    return brief
        ? ListTile(
            title: Text(item.title),
            subtitle: Text(item.description),
          )
        : Column(
            children: [
              ListTile(
                title: Text(item.title),
                subtitle: Text(item.description),
              ),
              const Divider(color: Color(0xffefefef)),
              Markdown(
                  selectable: !brief,
                  data: item.content,
                  shrinkWrap: true,
                  physics: const NeverScrollableScrollPhysics(),
                  extensionSet: md.ExtensionSet(
                    md.ExtensionSet.gitHubFlavored.blockSyntaxes,
                    md.ExtensionSet.gitHubFlavored.inlineSyntaxes,
                  ),
                  onTapLink: (text, href, title) async {
                    if (href == null) return;
                    await launchUrlString(
                      href,
                      mode: LaunchMode.externalApplication,
                    );
                  }),
            ],
          );
  }
}
